(this.webpackJsonpstreamlit_component_template=this.webpackJsonpstreamlit_component_template||[]).push([[0],{15:function(e,t,a){e.exports=a(25)},25:function(e,t,a){"use strict";a.r(t);var n=a(6),r=a.n(n),l=a(13),c=a.n(l),s=a(0),m=a(1),o=a(7),i=a(2),d=a(3),u=a(11),f=function(e){Object(i.a)(a,e);var t=Object(d.a)(a);function a(){var e;Object(m.a)(this,a);for(var n=arguments.length,l=new Array(n),c=0;c<n;c++)l[c]=arguments[c];return(e=t.call.apply(t,[this].concat(l))).state={selected_row:{}},e.render=function(){var t=JSON.parse(e.props.args.data),a=e.props.args.columns;console.log(a);e.props.theme;return r.a.createElement("div",{className:"table-responsive"},r.a.createElement("table",{className:"table table-striped table-hover"},r.a.createElement("thead",null,a.map((function(e){if(console.log(e),e.show)return r.a.createElement("th",{scope:"col"},e.label)}))),r.a.createElement("tbody",null,t.data.map((function(t){var n={display:"inline-block","font-size":"1.25rem",color:"#212529",cursor:"pointer","user-select":"none",padding:"0.5rem 1rem"},l={display:"inline-block","font-size":"1.25rem",color:"#dddddd",cursor:"default","user-select":"none",padding:"0.5rem 1rem"},c={height:50};return r.a.createElement("tr",null,a.map((function(a){if(a.show){if("STRING"===a.dtype)return a.switchcase?r.a.createElement("td",null,a.switchcase[t[a.name]]):r.a.createElement("td",null,t[a.name]);if("ICONBUTTON"===a.dtype)return t[a.name]&&""!==t[a.name]?r.a.createElement("td",{className:"align-middle text-center"},r.a.createElement("a",{href:t[a.name],target:"_blank",rel:"noopener noreferrer"},r.a.createElement("i",{style:n,className:a.icon}))):r.a.createElement("td",{className:"align-middle text-center"},r.a.createElement("i",{style:l,className:a.icon}));if("DOWNLOAD"===a.dtype)return t[a.name]&&""!==t[a.name]?r.a.createElement("td",{className:"align-middle text-center"},r.a.createElement("a",{href:t[a.name],target:"_blank",rel:"noopener noreferrer"},r.a.createElement("i",{style:n,className:"fa-solid fa-cloud-arrow-down"}))):r.a.createElement("td",{className:"align-middle text-center"},r.a.createElement("i",{style:l,className:"fa-solid fa-cloud-arrow-down"}));if("LINK"===a.dtype)return t[a.name]&&""!==t[a.name]?r.a.createElement("td",{className:"align-middle text-center"},r.a.createElement("a",{href:t[a.name],target:"_blank",rel:"noopener noreferrer"},r.a.createElement("i",{style:n,className:"fa-solid fa-up-right-from-square"}))):r.a.createElement("td",{className:"align-middle text-center"},r.a.createElement("i",{style:l,className:"fa-solid fa-up-right-from-square"}));if("IMAGE"===a.dtype)return t[a.name]&&""!==t[a.name]?r.a.createElement("td",{className:"align-middle text-center"},r.a.createElement("img",{style:c,src:t[a.name],alt:a.name})):r.a.createElement("td",{className:"align-middle text-center"});if("SET_STATE"===a.dtype){var s=t[a.icon]&&""!==t[a.icon]?t[a.icon]:"fa-solid fa-eye";return r.a.createElement("td",{className:"align-middle text-center"},r.a.createElement("i",{style:n,className:s,onClick:function(){return e.onClicked(t)}}))}return r.a.createElement("td",null)}}),Object(o.a)(e)))})))))},e.onClicked=function(t){e.setState((function(e){return{selected_row:t}}),(function(){return u.a.setComponentValue(e.state.selected_row)}))},e}return Object(s.a)(a)}(u.b),p=Object(u.c)(f);a(23),a(24);c.a.render(r.a.createElement(r.a.StrictMode,null,r.a.createElement(p,null)),document.getElementById("root"))}},[[15,1,2]]]);
//# sourceMappingURL=main.b1c2cc97.chunk.js.map